Statement

Enum Statement 

pub enum Statement {
    Emit(Range<Expression>),
    Store {
        pointer: Handle<Expression>,
        value: Handle<Expression>,
    },
    If {
        condition: Handle<Expression>,
        accept: Block,
        reject: Block,
    },
    Loop {
        body: Block,
        continuing: Block,
        break_if: Option<Handle<Expression>>,
    },
    Call {
        function: Handle<Function>,
        arguments: Vec<Handle<Expression>>,
        result: Option<Handle<Expression>>,
    },
    Atomic {
        pointer: Handle<Expression>,
        fun: AtomicFunction,
        value: Handle<Expression>,
        result: Option<Handle<Expression>>,
    },
    Break,
    Continue,
    Return {
        value: Option<Handle<Expression>>,
    },
    Barrier(Barrier),
}
A statement in the IR.

Statements have side effects and/or control flow. They operate on expressions referenced by handles.

Variants



Emit(Range<Expression>)

Mark a range of expressions as producing live values.



Store

Write a value through a pointer.

Fields



If

Conditional branch.

Fields

condition: Handle<Expression>
accept: Block
reject: Block


Loop

Unified loop construct (handles for/while/loop).

Fields

body: Block
continuing: Block


Call

Call a function.

Fields

function: Handle<Function>
arguments: Vec<Handle<Expression>>


Atomic

Perform an atomic operation.



Break

Break out of the innermost loop.



Continue

Continue to the next iteration of the innermost loop.



Return

Return from the function.

Fields



Barrier(Barrier)

Synchronization barrier.