pub fn format_type(ty: &Type, types: &UniqueArena<Type>) -> StringExpand description
Formats a type using the type arena for resolving inner references.
pub fn format_type(ty: &Type, types: &UniqueArena<Type>) -> StringFormats a type using the type arena for resolving inner references.